@@ -115,6 +115,15 @@ def get_attributes_from_type(setype):
     return info(TYPE, setype)[0]["attributes"]
 
 
+# determine if entered type is an alias
+# and return corresponding type name
+def get_real_type_name(setype):
+    try:
+        return info(TYPE, setype)[0]["name"]
+    except RuntimeError:
+        return None
+
+
 def file_type_is_executable(setype):
     if "exec_type" in get_attributes_from_type(setype):
         return True
@@ -934,7 +943,7 @@ def gen_short_name(setype):
         domainname = setype[:-2]
     else:
         domainname = setype
-    if domainname + "_t" not in all_domains:
+    if get_real_type_name(domainname + "_t") not in all_domains:
         raise ValueError("domain %s_t does not exist" % domainname)
     if domainname[-1] == 'd':
         short_name = domainname[:-1] + "_"
